@@ -8,7 +8,7 @@ use Test::POE::Client::TCP;
 use Carp qw(carp croak);
 use vars qw($VERSION);
 
-$VERSION = '1.46';
+$VERSION = '1.48';
 
 sub spawn {
   my $package = shift;
@@ -168,6 +168,10 @@ sub _cmdc_input {
   if ( $numeric eq '226' ) {
      $kernel->yield( '_retr_done' );
   }
+  if ( $numeric eq '221' ) {
+    $self->{cmdc}->shutdown();
+    delete $self->{cmdc};
+  }
   return;
 }
 
